@@ -35,8 +35,8 @@ static propval_t PROPENT_VSEL[] = { LB_CM, EA_Z, GB_Extend, SC_Inherited };
 /* Private use - XX */
 static propval_t PROPENT_PRIVATE[] = { LB_AL, EA_A, GB_Other, SC_Unknown };
 
-/* Surrogates or other unassigned - XX/SG */
-static propval_t PROPENT_UNKNOWN[] = { LB_AL, EA_N, GB_Other, SC_Unknown };
+/* Reserved or noncharacter - XX */
+static propval_t PROPENT_RESERVED[] = { LB_AL, EA_N, GB_Control, SC_Unknown };
 
 /** Search for character properties.
  * 
@@ -147,7 +147,7 @@ void linebreak_charprop(linebreak_t * obj, unichar_t c,
 		 (0x100000 <= c && c <= 0x10FFFD))
 	    ent = PROPENT_PRIVATE;
 	else
-	    ent = PROPENT_UNKNOWN;
+	    ent = PROPENT_RESERVED;
 
 	if (lbcptr && lbc == PROP_UNKNOWN)
 	    lbc = ent[0];
@@ -332,7 +332,7 @@ void _add_prop(linebreak_t * obj, unichar_t c, propval_t p, int idx)
  */
 void linebreak_update_lbclass(linebreak_t * obj, unichar_t c, propval_t p)
 {
-    return _add_prop(obj, c, p, 0);
+    _add_prop(obj, c, p, 0);
 }
 
 /** Update custom East_Asian_Width propety map.
@@ -345,7 +345,7 @@ void linebreak_update_lbclass(linebreak_t * obj, unichar_t c, propval_t p)
  */
 void linebreak_update_eawidth(linebreak_t * obj, unichar_t c, propval_t p)
 {
-    return _add_prop(obj, c, p, 1);
+    _add_prop(obj, c, p, 1);
 }
 
 static
@@ -389,7 +389,7 @@ void _clear_prop(linebreak_t * obj, int idx)
  */
 void linebreak_clear_lbclass(linebreak_t * obj)
 {
-    return _clear_prop(obj, 0);
+    _clear_prop(obj, 0);
 }
 
 /** Clear custom East_Asian_Width property map
@@ -400,5 +400,5 @@ void linebreak_clear_lbclass(linebreak_t * obj)
  */
 void linebreak_clear_eawidth(linebreak_t * obj)
 {
-    return _clear_prop(obj, 1);
+    _clear_prop(obj, 1);
 }
